# iustus

A semantic Python kernel for the Justus structural grammar framework.

> “존재는 반응이 아니라 흐름이다.”

This package is reserved for future development of tensor-based structural modeling tools under the Justus grammar system.
